%define ALD_Ver		2.0

Name:         openocd

License:      GPL
Summary:      OpenOCD provides on-chip programming and debugging
Version:      0.12.0
Release:      4

#https://sourceforge.net/projects/openocd/files/openocd/

Source: %{name}-%{version}.tar.xz
Source1: openocd.pdf
Source2: %{name}-%{version}.4-patches.tgz

#https://github.com/openocd-org/openocd/releases
#https://github.com/STMicroelectronics/OpenOCD

%define DestDir		/Compiler
# -----------------------------------------------------

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=armv7hl -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

#------------------ CROSS DIR --------------------

%define docdir		%{_defaultdocdir}/%{name}-%{version}

%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{have_auto_local}
%define __os_install_post %{nil}
%define CrossPath	%(%{auto_local} -GetCrossPath -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu})
%endif

# ------------------- description ------------------------------------
%description
OpenOCD provides on-chip programming and debugging
#-------------------------------
%package info
Summary:      Info for %{name}
%description info
Info for %{name}
#-------------------------------
%package pdf
Summary:      doc openocd.pdf
%description pdf
doc openocd.pdf

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

tar -xzf %SOURCE2
patch -p1<patches/stm32h5x.patch
cp -a patches/Makefile.am src/flash/nor/
patch -p0<patches/no_deprecated_mem2array.patch

# ------------------- Build ------------------------------------------
%Build 
%if %{_CROSS}
export PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -Os -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -fno-asynchronous-unwind-tables"

CFLAGS="$OPTFLAGS -std=gnu99"
CXXFLAGS="$OPTFLAGS"
LDFLAGS="-Wl,--gc-sections -ludev"

#autoreconf -fi

#aclocal
#automake
#autoconf

%configure \
  --disable-silent-rules \
  --disable-libtool-lock \
  --disable-ftdi \
    --enable-stlink \
  --disable-ti-icdi \
  --disable-ulink \
  --disable-usb-blaster-2 \
  --disable-ft232r \
  --disable-vsllink \
  --disable-xds110 \
    --enable-cmsis-dap-v2 \
  --disable-osbdm \
  --disable-opendous \
  --disable-aice \
  --disable-usbprog \
  --disable-rlink \
  --disable-armjtagew \
    --enable-cmsis-dap \
  --disable-nulink \
  --disable-kitprog \
  --disable-usb-blaster \
  --disable-presto \
  --disable-openjtag \
  --disable-jlink \
  --disable-parport \
  --disable-jtag_vpi \
  --disable-jtag_dpi \
  --disable-amtjtagaccel \
  --disable-zy1000-master \
  --disable-zy1000 \
  --disable-bcm2835gpio \
  --disable-imx_gpio \
  --disable-ep93xx \
  --disable-at91rm9200 \
  --disable-gw16012 \
  --disable-oocd_trace \
  --disable-buspirate \
  --disable-sysfsgpio \
  --disable-xlnx-pcie-xvc \
  --disable-minidriver-dummy \
  &>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
export PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>Finstall_log.txt
cp -a README $RPM_BUILD_ROOT%{docdir}/
cp -a %SOURCE1 $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/gpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING

rm -rf $RPM_BUILD_ROOT%{_infodir}/dir

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} -DelLocCrossDir=%{_bindir}
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
%{_bindir}
%{_datadir}/openocd
%{_mandir}
%dir %{docdir}
%{docdir}/COPYING
%{docdir}/README

%files info
%{_datadir}/info

%files pdf
%{docdir}/openocd.pdf
